function [c ic y] = evalSplineObj(splnObj,tpts,cpl,cps,dht)
%
% evaluate the spline object at specific points
% inputs:
%  - splnObj: ppStruct with spline coefficients
%  - tpts   : vector of temperature [C] evaluation points
%  - cpl    : (constant) liquid specific heat capacity [J/(kg*K)] or [kJ/(kg*K)]
%  - cps    : (constant) solid specific heat capacity  [J/(kg*K)] or [kJ/(kg*K)]
%  - dht    : phase transition enthalpy [J/kg] or [kJ/kg]
% outputs: 
%  - c      : apparent specific heat capacity [J/(kg*K)] or [kJ/(kg*K)]
%  - ic     : specific enthalpy [J/kg] or [kJ/kg]
%  - y      : liquid mass phase fraction [kg/kg]
% 
% for details see: 
%  Identification of phase fraction-temperature curves from heat capacity 
%  data for numerical modeling of heat transfer in commercial paraffin waxes
%  Tilman Barz, Johannes Krmer, and Johann Emhofer
%  Energies
% 
% tilman.barz@ait.ac.at
% 17/09/2020
% 

breaks = splnObj.breaks;
order  = splnObj.order;
pieces = splnObj.pieces;
coefs  = splnObj.coefs;

if ~isempty(find( (tpts < breaks(1) ))) ...
        || ~isempty(find( tpts > breaks(end) ))
    error('Values outside the evaluation range!');
end


tpts = tpts(:);

nO = length(coefs(1,:))-1;
nI = pieces;

c    = zeros(length(tpts),1);
ic   = zeros(length(tpts),1);
iy   = zeros(length(tpts),1);
y    = zeros(length(tpts),1);
dy   = zeros(length(tpts),1);
    

% --- loop for breaks within the phase trans temperature range ---
for io = 1:nI
    vonBis = breaks([io,io+1]);
    if (io == pieces) % only for last element
    els = find(   (vonBis(1)<= tpts) ...
                & (tpts <= vonBis(2))  );
    else
    els = find(   (vonBis(1)<= tpts) ...
                & (tpts <  vonBis(2))  );
    end
    if isempty(els) 
        continue; 
    end
    
    p = coefs(io,:);
    dx = tpts(els) - breaks(io);

    for jk = 1:nO+1 % evaluate spline - coefs give integral values
    iy(els)  = iy(els) +  p(jk).*dx(:).^(jk-1);
    end
    for jk = 2:nO+1 % 1st derivative 
    y(els) = y(els) +  (jk-1).*p(jk).*dx(:).^(jk-2);
    end
    for jk = 3:nO+1 % 2nd derivative 
    dy(els)  = dy(els) ...
             + (jk-2).*(jk-1).*p(jk).*dx(:).^(jk-3);
    end
    
     c(els) =   y(els)*cpl + (1.0      - y(els))*cps + dy(els)*dht;
     
    ic(els) =  iy(els)*cpl + (tpts(els)-iy(els))*cps +  y(els)*dht;
 
end

end

